@@ -78,10 +78,11 @@ class PersistedRmq(object):
         while True:
             message = await self.conn.lpop(self.queue_key)
             if not message:
-                logging.error('没有旧消息了，退出循环')
+                logging.error(f'没有旧消息了，退出循环:{self.queue_key}')
                 return False
             try:
                 await self.on_message(message)
+                logging.error(f'下发了缓存的消息on queue:{self.queue_key}\n{message}')
             except Exception as e:
                 await self.conn.rpush(self.queue_key, message)
                 logging.error(e)
@@ -111,12 +112,12 @@ class PersistedRmq(object):
                 except Exception as e:
                     await self.conn.unsubscribe(self.subscribe_chn)
                     if await self.duplicate():
-                        logging.error('有另外一个实例连接上来了，就不用发了')
+                        logging.error(f'{self.queue_key} 有另外一个实例连接上来了，就不用发了')
                     else:
                         await self.conn.rpush(self.queue_key, msg)
                         await self.expire(self.queue_key, self.persisted_timeout)
                         await self.hash_set(self.queue_key)
-                        logging.error('下发通道关闭，向错误队列push')
+                        logging.error(f'{self.queue_key} 下发通道关闭，向错误队列push')
                     await self.close()
                     return
 
